@@ -1,8 +1,9 @@
 package Net::Redmine;
 use Any::Moose;
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 use Net::Redmine::Connection;
 use Net::Redmine::Ticket;
+use Net::Redmine::Search;
 
 has connection => (
     is => "ro",
@@ -51,6 +52,17 @@ sub lookup_ticket {
     }
 }
 
+sub search_ticket {
+    my ($self, $query) = @_;
+
+    my $search = Net::Redmine::Search->new(
+        connection => $self->connection,
+        type => ['ticket'],
+        query => $query
+    );
+    return $search;
+}
+
 1;
 __END__
 
